@@ -49,9 +49,16 @@
 
 package com.openexchange.mobile.api.facade.models;
 
+import java.util.List;
+
+import lombok.AllArgsConstructor;
 import lombok.Data;
+import lombok.NoArgsConstructor;
+import lombok.experimental.Wither;
 
 @Data
+@NoArgsConstructor
+@AllArgsConstructor
 public class Config {
 
     private boolean purgeOnDeletion;
@@ -64,4 +71,7 @@ public class Config {
 
     private String namespace;
 
+    @Wither
+    private List<Capability> capabilities;
+
 }
