@@ -94,6 +94,11 @@ public class AccountsService {
         return ListUtil.map(accountMtos, accountsToIdsMapFunction);
     }
 
+    public List<Account> getAccounts(SessionData sessionData) {
+        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
+        return getAccounts(connectorFactory, sessionData);
+    }
+
     public List<Account> getAccounts(final ConnectorFactory connectorFactory, final SessionData sessionData) {
         List<AccountMto> accountMtos = retrieveAccounts(connectorFactory, sessionData);
         final UserMto userMto = retrieveUserMto(connectorFactory, sessionData);
